@@ -86,7 +86,7 @@
 #define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KXMLGUI_NO_DEPRECATED
-#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
+#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54b00
 #endif
 #ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
 #  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x54a00
+#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x54b00
 #  endif
 #endif
 
@@ -127,6 +127,12 @@
 #else
 #  define KXMLGUI_DEPRECATED_VERSION_5_0(text)
 #endif
+
+#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x54b00
+#  define KXMLGUI_DEPRECATED_VERSION_5_75(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KXMLGUI_DEPRECATED_VERSION_5_75(text)
+#endif
 #define KXMLGUI_DEPRECATED_VERSION_4(minor, text)      KXMLGUI_DEPRECATED_VERSION_4_##minor(text)
 #define KXMLGUI_DEPRECATED_VERSION_5(minor, text)      KXMLGUI_DEPRECATED_VERSION_5_##minor(text)
 #define KXMLGUI_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
